@@ -3,7 +3,7 @@
 : ${HEALTHCHECK_CURL_WRITE_OUT:='\n%{http_code} %{remote_ip}:%{remote_port} %{time_total} seconds\n'}
 
 healthcheck_curl () {
-  curl -g -q --fail \
+  curl -g -k -q --fail \
     --max-time "${HEALTHCHECK_CURL_MAX_TIME}" \
     --user-agent "${HEALTHCHECK_CURL_USER_AGENT}" \
     --write-out "${HEALTHCHECK_CURL_WRITE_OUT}" \
@@ -50,9 +50,13 @@ get_url_from_vhost () {
   server_name=$(awk '/ServerName/ {print $2}' $vhost_file)
   ssl_enabled=$(awk '/SSLEngine/ {print $2}' $vhost_file)
   bind_port=$(grep -h "<VirtualHost .*>" $vhost_file | sed 's/<VirtualHost .*:\(.*\)>/\1/')
+  wsgi_alias=$(awk '/WSGIScriptAlias/ {print $2}' $vhost_file)
   proto=http
   if [[ $ssl_enabled == "on" ]]; then
     proto=https
   fi
-  echo ${proto}://${server_name}:${bind_port}/
+  if [[ $wsgi_alias != "/" ]]; then
+    wsgi_alias="${wsgi_alias}/"
+  fi
+  echo ${proto}://${server_name}:${bind_port}${wsgi_alias}
 }
